@@ -2,6 +2,6 @@
 
 set -eox pipefail
 
-rpm -Uvh /tmp/*.rpm
+rpm --replacepkgs --replacefiles --oldpackage -Uvh /tmp/*.rpm
 rm -f /tmp/*.rpm
 rm -f /tmp/rpm_install.sh
